@@ -110,7 +110,7 @@ impl TryFrom<ChainSpec> for SpecHashes {
     }
 }
 
-pub fn list_hashes(root_dir: PathBuf, matches: &ArgMatches<'_>) -> Result<(), ExitCode> {
+pub fn list_hashes(root_dir: PathBuf, matches: &ArgMatches) -> Result<(), ExitCode> {
     let mut specs = Vec::new();
 
     if matches.is_present(cli::ARG_BUNDLED) {
